package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
)

var _ DcWorkingPumpModel = (*customDcWorkingPumpModel)(nil)

type (
	// DcWorkingPumpModel is an interface to be customized, add more methods here,
	// and implement the added methods in customDcWorkingPumpModel.
	DcWorkingPumpModel interface {
		dcWorkingPumpModel
		FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingPump, error)
	}

	customDcWorkingPumpModel struct {
		*defaultDcWorkingPumpModel
	}
)

// NewDcWorkingPumpModel returns a model for the database table.
func NewDcWorkingPumpModel(conn sqlx.SqlConn) DcWorkingPumpModel {
	return &customDcWorkingPumpModel{
		defaultDcWorkingPumpModel: newDcWorkingPumpModel(conn),
	}
}

func (m *defaultDcWorkingPumpModel) FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingPump, error) {
	var resp DcWorkingPump
	query := fmt.Sprintf("select %s from %s where `project_id` = ? and `device_code` = ? order by c_time desc limit 1", dcWorkingPumpRows, m.table)
	err := m.conn.QueryRowCtx(ctx, &resp, query, projectId, deviceCode)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}
